@@ -6,12 +6,12 @@ from worker.data.api import API
 from worker.framework import constants
 from worker.mixins.logging import LoggingMixin
 from worker.mixins.rollbar import RollbarMixin
-from worker.state.mixins import StateMixin
+from worker.state.mixins import RedisMixin
 
 from worker.state.state import State
 
 
-class Module(StateMixin, LoggingMixin, RollbarMixin):
+class Module(RedisMixin, LoggingMixin, RollbarMixin):
     """
     This is an abstract base module that needs to be extended by an actual module.
     """
@@ -29,10 +29,6 @@ class Module(StateMixin, LoggingMixin, RollbarMixin):
         self.app_name = constants.get('global.app-name')
         self.asset_id = global_state.get("asset_id")
 
-        state_storage_type = constants.get("global.state_storage_type", None)
-        if state_storage_type:
-            kwargs["state_storage_type"] = state_storage_type
-
         self.global_state = global_state
 
         super().__init__(*args, **kwargs)
@@ -43,7 +39,7 @@ class Module(StateMixin, LoggingMixin, RollbarMixin):
         :return:
         """
         # load the state
-        state = self.load_state()
+        state = self.get_state()
         self.state = self.process_module_state(state)
 
         # subclasses should implement their own run
@@ -51,8 +47,8 @@ class Module(StateMixin, LoggingMixin, RollbarMixin):
     def should_run_processor(self, event):
         raise Exception("This method need to be implemented by subclasses!")
 
-    def load_state(self, state_key: [str, None] = None, auto_migrate: bool = False, raise_warnings: bool = False) -> dict:
-        current_state = super().load_state(state_key=state_key, auto_migrate=auto_migrate, raise_warnings=raise_warnings)
+    def get_state(self, state_key: [str, None] = None, raise_warnings: bool = False) -> dict:
+        current_state = super().load_state(state_key=state_key, raise_warnings=raise_warnings)
         return State(self.module_state_fields, current_state)
 
     @staticmethod
@@ -62,12 +58,6 @@ class Module(StateMixin, LoggingMixin, RollbarMixin):
     def set_state(self, key, value):
         self.state[key] = value
 
-    def save_state(self, state_key: [str, None] = None, timestamp: [int, None] = None, raise_warnings: bool = True) -> None:
-        if not timestamp:
-            timestamp = self.global_state.get('last_processed_timestamp', 0)
-
-        super().save_state(state_key=state_key, timestamp=timestamp, raise_warnings=raise_warnings)
-
     def load_dataset(self, event):
         return event
 
