@@ -32,7 +32,7 @@ class Wellbore:
     def __init__(self, **kwargs):
         super().__init__()
 
-        self.under_reamer: [UnderReamer, None] = None
+        self.under_reamer: Union[UnderReamer, None] = None
         self.under_reamer_alert_timestamp: float = 0.0
 
         self.original_drillstring: Drillstring = kwargs.get('original_drillstring') or kwargs.get('drillstring')
@@ -179,7 +179,7 @@ class Wellbore:
         self.actual_hole.insert_section_after(under_reamer_hole, current_hole)
         self.actual_hole.insert_section_after(bottom_hole, under_reamer_hole)
 
-    def update_drillstring_api(self, drillstring: dict) -> [dict, None]:
+    def update_drillstring_api(self, drillstring: dict) -> Union[dict, None]:
         try:
             path = "/v1/data/corva/data.drillstring"
             res = API().post(path=path, data=json.dumps(drillstring))
